---
name: Feature request
about: Suggest an idea for this project
title: ''
labels: enhancement
assignees: ''

---

<!-- Provide a general summary of the feature you would like to see -->

## Detailed Description
<!-- Provide a detailed description of the change or addition you are proposing -->

## Context
<!-- Why is this change important to you? -->
<!-- How would you use it? -->

## Possible Implementation
<!-- Not obligatory, but suggest an idea for implementing addition or change -->
